# Card progress (name in Chinese)

- [X] 不动玄石之相
- [X] 教官的帽子
- [X] 焦灼的魔女帽
- [X] 流放者头冠
- [X] 月桂的宝冠
- [X] 破冰踏雪的回音
- [X] 幸运儿银冠
- [X] 唤雷的头冠
- [X] 翠绿的猎人之冠
- [X] 酒渍船帽
- [X] 华饰之兜
- [X] 虺雷之姿
- [X] 辰砂往生录
- [X] 无常之面
- [X] 追忆之注连
- [X] 赌徒的耳环
- [X] 沉沦之心
- [X] 深林的记忆
- [X] 悠古的磐岩
- [X] 冒险家头带
- [X] 炽烈的炎之魔女
- [X] 冰风迷途的勇士
- [X] 游医的方巾
- [X] 如雷的盛怒
- [X] 翠绿之影
- [X] 将帅兜鍪
- [X] 千岩牢固
- [X] 绝缘之旗印
- [X] 寒天宣命祝词
- [X] 烬火重燃
- [X] 脉冲的魔女
- [X] 唯此一心
- [X] 猫爪冰摇
- [X] 冷血之剑
- [X] 吐纳真定
- [X] 战欲涌现
- [X] 冰萤寒光
- [X] 忘玄
- [X] 起死回骸
- [X] 储之千日，用之一刻
- [X] 支援就交给我吧
- [X] 重铸：岩盔
- [X] 荒泷第一
- [X] 炊金馔玉
- [X] 神性之陨
- [X] 重帘留香
- [X] 沉没的预言
- [X] 百川奔流
- [X] 光辉的季节
- [X] 镜锢之笼
- [X] 匣中玉栉
- [X] 镜华风姿
- [X] 深渊之灾·凝水盛放
- [X] 衍溢的汐潮
- [X] 长野原龙势流星群
- [X] 悉数讨回
- [X] 流火焦灼
- [X] 交叉火力
- [X] 冒险憧憬
- [X] 砰砰礼物
- [X] 一触即发
- [X] 血之灶火
- [X] 最终解释权
- [X] 飞叶迴斜
- [X] 孢子增殖
- [X] 眼识殊明
- [X] 心识蕴藏之种
- [X] 噬星魔鸦
- [X] 觉醒
- [X] 抵天雷罚
- [X] 落羽的裁择
- [X] 霹雳连霄
- [X] 我界
- [X] 神篱之御荫
- [X] 万千的愿望
- [X] 机巧神通
- [X] 蒲公英的国土
- [X] 混元熵增论
- [X] 绪风之拥
- [X] 降魔·护法夜叉
- [X] 风物之诗咏
- [X] 祭礼剑
- [X] 风鹰剑
- [X] 旅行剑
- [X] 西风剑
- [X] 天空之刃
- [X] 狼的末路
- [X] 白铁大剑
- [X] 祭礼大剑
- [X] 钟剑
- [X] 天空之傲
- [X] 鸦羽弓
- [X] 祭礼弓
- [X] 天空之翼
- [X] 阿莫斯之弓
- [X] 终末嗟叹之诗
- [X] 王下近侍
- [X] 盈满之实
- [X] 天空之卷
- [X] 魔导绪论
- [X] 祭礼残章
- [X] 千夜浮梦
- [X] 白缨枪
- [X] 千岩长枪
- [X] 天空之脊
- [X] 贯虹之槊
- [X] 薙草之稻光
- [X] 刘苏
- [X] 蒂玛乌斯
- [X] 阿圆
- [X] 卯师傅
- [X] 提米
- [X] 田铁嘴
- [X] 立本
- [X] 派蒙
- [X] 常九爷
- [X] 凯瑟琳
- [X] 艾琳
- [X] 瓦格纳
- [X] 迪娜泽黛
- [X] 拉娜
- [X] 花散里
- [X] 鲸井小弟
- [X] 旭东
- [X] 老章
- [X] 塞塔蕾
- [X] 望舒客栈
- [X] 西风大教堂
- [X] 璃月港口
- [X] 骑士团图书馆
- [X] 群玉阁
- [X] 晨曦酒庄
- [X] 鸣神大社
- [X] 桓那兰那
- [X] 镇守之森
- [X] 天守阁
- [X] 须弥城
- [X] 珊瑚宫
- [X] 黄金屋
- [X] 参量质变仪
- [X] 便携营养袋
- [X] 红羽团扇
- [X] 寻宝仙灵
- [X] 元素共鸣：交织之水
- [X] 元素共鸣：蔓生之草
- [X] 元素共鸣：交织之风
- [X] 元素共鸣：愈疗之水
- [X] 元素共鸣：迅捷之风
- [X] 元素共鸣：交织之火
- [X] 元素共鸣：交织之岩
- [X] 元素共鸣：热诚之火
- [X] 元素共鸣：交织之冰
- [X] 元素共鸣：坚定之岩
- [X] 元素共鸣：交织之雷
- [X] 元素共鸣：粉碎之冰
- [X] 元素共鸣：交织之草
- [X] 元素共鸣：强能之雷
- [X] 汲能棱晶
- [X] 下落斩
- [X] 兽肉薄荷卷
- [X] 莲花酥
- [X] 北地烟熏鸡
- [X] 甜甜花酿鸡
- [X] 蒙德土豆饼
- [X] 绝云锅巴
- [X] 烤蘑菇披萨
- [X] 仙跳墙
- [X] 黄油蟹蟹
- [X] 提瓦特煎蛋
- [X] 刺身拼盘
- [X] 唐杜尔烤鸡
- [X] 本大爷还没有输！
- [X] 送你一程
- [X] 交给我吧！
- [X] 最好的伙伴！
- [X] 护法之誓
- [X] 鹤归之时
- [X] 换班时间
- [X] 深渊的呼唤
- [X] 白垩之术
- [X] 星天之兆
- [X] 一掷乾坤
- [X] 诸武精通
- [X] 快快缝补术
- [X] 运筹帷幄
- [X] 神宝迁宫祝词
- [X] 永远的友谊
- [X] 愚人众的阴谋
- [X] 风与自由
- [X] 重攻击
- [X] 岩与契约
- [X] 温妮莎传奇
- [X] 雷与永恒
- [X] 草与智慧
- [X] 大梦的曲调
- [X] 藏锋何处
- [X] 旧时庭园
- [X] 磐岩盟契
- [X] 愉舞欢游